@@ -120,7 +120,7 @@ class WorkerServer(BaseServer):
         self.auth = yield self.conn.authenticate(
             self.amqp_username,
             self.amqp_password)
-        self.chan = yield self.conn.channel(random.randint(2, 999))
+        # self.chan = yield self.conn.channel(random.randint(2, 999))
         yield self.chan.channel_open()
         yield self.chan.basic_qos(prefetch_count=self.amqp_prefetch_count)
         # Create Queue
@@ -139,7 +139,7 @@ class WorkerServer(BaseServer):
             queue=self.amqp_queue,
             exchange=self.amqp_exchange)
         yield self.chan.basic_consume(queue=self.amqp_queue,
-            no_ack=False,
+            no_ack=True,
             consumer_tag="awspider_consumer")
         self.queue = yield self.conn.queue("awspider_consumer")
         yield BaseServer.start(self)
@@ -226,24 +226,17 @@ class WorkerServer(BaseServer):
         self.jobs_complete += 1
         LOGGER.debug('Completed Jobs: %d / Queued Jobs: %d / Active Jobs: %d' % (self.jobs_complete, len(self.job_queue), len(self.active_jobs)))
         # FIXME basic_ack giving error "txamqp.client.Closed: Method(name=close, id=60) (503, 'COMMAND_INVALID - unknown delivery tag 15421', 60, 80) content = None"
-        if job.has_key('delivery_tag') and job['delivery_tag']:
-            LOGGER.debug('basic_ack for delivery_tag: %s' % job['delivery_tag'])
-            d = self.chan.basic_ack(delivery_tag=job['delivery_tag'])
-            d.addCallback(self._basicAckCallback)
-            d.addErrback(self.basicAckErrback)
-        else:
-            return True
+        # if job.has_key('delivery_tag') and job['delivery_tag']:
+        #             LOGGER.debug('basic_ack for delivery_tag: %s' % job['delivery_tag'])
+        #             d = self.chan.basic_ack(delivery_tag=job['delivery_tag'])
+        #             d.addCallback(self._basicAckCallback)
+        #             d.addErrback(self.basicAckErrback)
         
     def workerErrback(self, error, function_name='Worker', delivery_tag=None):
         LOGGER.error('%s Error: %s' % (function_name, str(error)))
         LOGGER.debug('Queued Jobs: %d / Active Jobs: %d' % (len(self.job_queue), len(self.active_jobs)))
         LOGGER.debug('Active Jobs List: %s' % repr(self.active_jobs))
         self.pending_dequeue = False
-        if delivery_tag:
-            LOGGER.debug('basic_ack for delivery_tag: %s' % delivery_tag)
-            d = self.chan.basic_ack(delivery_tag=delivery_tag)
-            d.addCallback(self._basicAckCallback)
-            d.addErrback(self.basicAckErrback)
         return error
         
     def _basicAckCallback(self, data):
